summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWim Taymans <wtaymans@redhat.com>2016-03-04 17:13:59 +0100
committerWim Taymans <wtaymans@redhat.com>2016-03-04 17:17:33 +0100
commitc0ef1ea5533673995bd3cc1f8eb05ca2a9251e96 (patch)
tree79176768b8efcc816dffb098f351a2b3a06af1e1
parent509d4a0f92e160f028d4b50052c601bd8b0b42b6 (diff)
downloadgstreamer-plugins-base-c0ef1ea5533673995bd3cc1f8eb05ca2a9251e96.tar.gz
audio-channel-mixer: improve non-interleaved flags
Make separate flags for non-interleaved input and output because the channel mixer should be able to convert between the two layouts in the future.
-rw-r--r--gst-libs/gst/audio/audio-channel-mixer.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/gst-libs/gst/audio/audio-channel-mixer.h b/gst-libs/gst/audio/audio-channel-mixer.h
index 90f6a5746..813ef3522 100644
--- a/gst-libs/gst/audio/audio-channel-mixer.h
+++ b/gst-libs/gst/audio/audio-channel-mixer.h
@@ -31,17 +31,19 @@ typedef struct _GstAudioChannelMixer GstAudioChannelMixer;
/**
* GstAudioChannelMixerFlags:
* @GST_AUDIO_CHANNEL_MIXER_FLAGS_NONE: no flag
* @GST_AUDIO_CHANNEL_MIXER_FLAGS_NON_INTERLEAVED: channels are not interleaved
* @GST_AUDIO_CHANNEL_MIXER_FLAGS_UNPOSITIONED_IN: input channels are explicitly unpositioned
* @GST_AUDIO_CHANNEL_MIXER_FLAGS_UNPOSITIONED_OUT: output channels are explicitly unpositioned
*
* Flags passed to gst_audio_channel_mixer_new()
*/
typedef enum {
- GST_AUDIO_CHANNEL_MIXER_FLAGS_NONE = 0,
- GST_AUDIO_CHANNEL_MIXER_FLAGS_NON_INTERLEAVED = (1 << 0),
- GST_AUDIO_CHANNEL_MIXER_FLAGS_UNPOSITIONED_IN = (1 << 1),
- GST_AUDIO_CHANNEL_MIXER_FLAGS_UNPOSITIONED_OUT = (1 << 2)
+ GST_AUDIO_CHANNEL_MIXER_FLAGS_NONE = 0,
+ GST_AUDIO_CHANNEL_MIXER_FLAGS_NON_INTERLEAVED_IN = (1 << 0),
+ GST_AUDIO_CHANNEL_MIXER_FLAGS_NON_INTERLEAVED_OUT = (1 << 1),
+ GST_AUDIO_CHANNEL_MIXER_FLAGS_UNPOSITIONED_IN = (1 << 2),
+ GST_AUDIO_CHANNEL_MIXER_FLAGS_UNPOSITIONED_OUT = (1 << 3)
} GstAudioChannelMixerFlags;
GstAudioChannelMixer * gst_audio_channel_mixer_new (GstAudioChannelMixerFlags flags,
@@ -31,17 +31,19 @@ typedef struct _GstAudioChannelMixer GstAudioChannelMixer;
* GstAudioChannelMixerFlags:
* @GST_AUDIO_CHANNEL_MIXER_FLAGS_NONE: no flag
- * @GST_AUDIO_CHANNEL_MIXER_FLAGS_NON_INTERLEAVED: channels are not interleaved
+ * @GST_AUDIO_CHANNEL_MIXER_FLAGS_NON_INTERLEAVED_IN: input channels are not interleaved
+ * @GST_AUDIO_CHANNEL_MIXER_FLAGS_NON_INTERLEAVED_OUT: output channels are not interleaved
* @GST_AUDIO_CHANNEL_MIXER_FLAGS_UNPOSITIONED_IN: input channels are explicitly unpositioned
* @GST_AUDIO_CHANNEL_MIXER_FLAGS_UNPOSITIONED_OUT: output channels are explicitly unpositioned